@@ -5,7 +5,8 @@
 
 use super::{app, icon::create_icns_file};
 use crate::{
-  bundle::{common::CommandExt, settings::Arch, Bundle},
+  bundle::{settings::Arch, Bundle},
+  utils::CommandExt,
   PackageType, Settings,
 };
 
@@ -173,9 +174,11 @@ pub fn bundle_project(settings: &Settings, bundles: &[Bundle]) -> crate::Result<
 
   // Issue #592 - Building MacOS dmg files on CI
   // https://github.com/tauri-apps/tauri/issues/592
-  if let Some(value) = env::var_os("CI") {
-    if value == "true" {
-      bundle_dmg_cmd.arg("--skip-jenkins");
+  if env::var_os("TAURI_BUNDLER_DMG_IGNORE_CI").unwrap_or_default() != "true" {
+    if let Some(value) = env::var_os("CI") {
+      if value == "true" {
+        bundle_dmg_cmd.arg("--skip-jenkins");
+      }
     }
   }
 
