@@ -5,8 +5,9 @@
 import 'uno.css'
 import './app.css'
 import App from './App.svelte'
+import { mount } from 'svelte'
 
-const app = new App({
+const app = mount(App, {
   target: document.querySelector('#app')
 })
 
